Tadau
=====

Tadau offers a sample on how to TrAck Downloads, Adaption and Usage of Solutions.

Requirements
------------
* Python 3.7+

Installation
------------
.. code-block::

  pip install tadau
